@@ -56,6 +56,7 @@ EkosManager::EkosManager()
     captureProcess = NULL;
     focusProcess   = NULL;
     guideProcess   = NULL;
+    alignProcess   = NULL;
 
     kcfg_localMode->setChecked(Options::localMode());
     kcfg_remoteMode->setChecked(Options::remoteMode());
@@ -243,6 +244,7 @@ void EkosManager::reset()
     captureProcess = NULL;
     focusProcess   = NULL;
     guideProcess   = NULL;
+    alignProcess   = NULL;
 
     connectB->setEnabled(false);
     disconnectB->setEnabled(false);
@@ -840,6 +842,14 @@ void EkosManager::setCCD(ISD::GDInterface *ccdDevice)
 
         ccdStarted = true;
 
+        // TODO: Add check #ifdef for astrometrynet & WSC here
+#ifdef HAVE_ASTROMETRYNET
+        initAlign();
+        alignProcess->setCCD(ccd);
+        if (scope && scope->isConnected())
+            alignProcess->setTelescope(scope);
+#endif
+
         // If guider is the same driver as the CCD
         if (useGuiderFromCCD == true)
         {
@@ -926,7 +936,18 @@ void EkosManager::processNewNumber(INumberVectorProperty *nvp)
     if (!strcmp(nvp->name, "TELESCOPE_INFO"))
     {
         if (guideProcess)
+        {
+           guideProcess->setTelescope(scope);
            guideProcess->syncTelescopeInfo();
+        }
+
+#ifdef HAVE_ASTROMETRYNET
+        if (alignProcess)
+        {
+            alignProcess->setTelescope(scope);
+            alignProcess->syncTelescopeInfo();
+        }
+#endif
 
     }
 
@@ -940,7 +961,7 @@ void EkosManager::processNewNumber(INumberVectorProperty *nvp)
 
 void EkosManager::processNewProperty(INDI::Property* prop)
 {
-    if (!strcmp(prop->getName(), "CCD_INFO") || !strcmp(prop->getName(), "GUIDE_INFO"))
+    if (!strcmp(prop->getName(), "CCD_INFO") || !strcmp(prop->getName(), "GUIDER_INFO"))
     {
         if (guideProcess)
             guideProcess->syncCCDInfo();
@@ -992,6 +1013,10 @@ void EkosManager::updateLog()
 
     if (currentWidget == setupTab)
         ekosLogOut->setPlainText(logText.join("\n"));
+#ifdef HAVE_ASTROMETRYNET
+    else if (currentWidget == alignProcess)
+        ekosLogOut->setPlainText(alignProcess->getLogText());
+#endif
     else if (currentWidget == captureProcess)
         ekosLogOut->setPlainText(captureProcess->getLogText());
     else if (currentWidget == focusProcess)
@@ -1018,13 +1043,16 @@ void EkosManager::clearLog()
         logText.clear();
         updateLog();
     }
+#ifdef HAVE_ASTROMETRYNET
+    else if (currentWidget == alignProcess)
+        alignProcess->clearLog();
+#endif
     else if (currentWidget == captureProcess)
         captureProcess->clearLog();
     else if (currentWidget == focusProcess)
         focusProcess->clearLog();
     else if (currentWidget == guideProcess)
         guideProcess->clearLog();
-
 }
 
 void EkosManager::initCapture()
@@ -1038,6 +1066,19 @@ void EkosManager::initCapture()
 
 }
 
+void EkosManager::initAlign()
+{
+#ifdef HAVE_ASTROMETRYNET
+    if (alignProcess)
+        return;
+
+     alignProcess = new Ekos::Align();
+     toolsWidget->addTab( alignProcess, i18n("Alignment"));
+     connect(alignProcess, SIGNAL(newLog()), this, SLOT(updateLog()));
+#endif
+}
+
+
 void EkosManager::initFocus()
 {
     if (focusProcess)
@@ -1083,6 +1124,9 @@ void EkosManager::removeTabs()
         for (int i=2; i < toolsWidget->count(); i++)
                 toolsWidget->removeTab(i);
 
+        delete (alignProcess);
+        alignProcess = NULL;
+
         ccd = NULL;
         delete (captureProcess);
         captureProcess = NULL;
