@@ -24,7 +24,7 @@
 #include <Eigen/Core>
 USING_PART_OF_NAMESPACE_EIGEN
 
-#include <math.h>
+#include <cmath>
 
 #include <QPointF>
 
@@ -52,7 +52,7 @@ public:
     /** Constructor.
       * @param p the ViewParams for this projection
       */
-    Projector( const ViewParams& p );
+    explicit Projector( const ViewParams& p );
 
     virtual ~Projector();
 
