@@ -84,6 +84,10 @@ SkyGLPainter::SkyGLPainter( QGLWidget *widget ) :
 
 void SkyGLPainter::drawBuffer(int type)
 {
+    // Prevent crash if type > UNKNOWN
+    if (type > SkyObject::TYPE_UNKNOWN)
+        type = SkyObject::TYPE_UNKNOWN;
+
     //printf("Drawing buffer for type %d, has %d objects\n", type, m_idx[type]);
     if( m_idx[type] == 0 ) return;
 
@@ -122,7 +126,11 @@ bool SkyGLPainter::addItem(SkyPoint* p, int type, float width, char sp)
     bool visible = false;
     Vector2f vec = m_proj->toScreenVec(p,true,&visible);
     if(!visible) return false;
-    
+
+    // Prevent crash if type > UNKNOWN
+    if (type > SkyObject::TYPE_UNKNOWN)
+        type = SkyObject::TYPE_UNKNOWN;
+
     //If the buffer is full, flush it
     if(m_idx[type] == BUFSIZE) {
         drawBuffer(type);
@@ -271,6 +279,11 @@ bool SkyGLPainter::drawDeepSkyObject(DeepSkyObject* obj, bool drawImage)
     if( !m_proj->checkVisibility(obj) )
         return false;
     int type = obj->type();
+
+    // Prevent crash if type > UNKNOWN
+    if (type > SkyObject::TYPE_UNKNOWN)
+        type = SkyObject::TYPE_UNKNOWN;
+
     //addItem(obj, type, obj->a() * dms::PI * Options::zoomFactor() / 10800.0);
     
     //If it's a star, add it like a star
@@ -365,14 +378,11 @@ void SkyGLPainter::drawSkyPolygon(LineList* list)
         isVisibleLast = isVisible;
     }
 
-    #define MAKE_KSTARS_SLOW TRUE
+    // false -> makes kstars slower but is always accurate
+    // true -> faster but potentially results in incorrect rendering
+    #define KSTARS_ASSUME_CONVEXITY false
     if ( polygon.size() ) {
-        #ifdef MAKE_KSTARS_SLOW
-        drawPolygon(polygon, false);
-        #else
-        //Assume convexity
-        drawPolygon(polygon, true);
-        #endif
+        drawPolygon(polygon, KSTARS_ASSUME_CONVEXITY);
     }
 }
 
